"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_segments_api import ConfigurationSegmentsApi  # noqa: E501


class TestConfigurationSegmentsApi(unittest.TestCase):
    """ConfigurationSegmentsApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationSegmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_segment(self):
        """Test case for create_segment

        """
        pass

    def test_delete_segment(self):
        """Test case for delete_segment

        """
        pass

    def test_edit_segment(self):
        """Test case for edit_segment

        """
        pass

    def test_get_segment(self):
        """Test case for get_segment

        """
        pass

    def test_get_segments(self):
        """Test case for get_segments

        """
        pass


if __name__ == '__main__':
    unittest.main()
