"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.advanced_radio_setting import AdvancedRadioSetting
from openapi_client.model.corporate_wifi import CorporateWifi
from openapi_client.model.guest_wifi import GuestWifi
from openapi_client.model.profile_parcel import ProfileParcel
from openapi_client.model.ssid_config import SSIDConfig
from openapi_client.model.variable import Variable
from openapi_client.model.wifi_all_of import WifiAllOf
globals()['AdvancedRadioSetting'] = AdvancedRadioSetting
globals()['CorporateWifi'] = CorporateWifi
globals()['GuestWifi'] = GuestWifi
globals()['ProfileParcel'] = ProfileParcel
globals()['SSIDConfig'] = SSIDConfig
globals()['Variable'] = Variable
globals()['WifiAllOf'] = WifiAllOf
from openapi_client.model.wifi import Wifi


class TestWifi(unittest.TestCase):
    """Wifi unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWifi(self):
        """Test Wifi"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Wifi()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
